<p align="center">
    <img src="https://res.cloudinary.com/dyzls6yws/image/upload/v1593924098/dipor-header.png">
    <p><b>UNDER PROCESS</b></p>
</p>

<p align="center">
    <h2>DIPOR</h2>
    <p><em>A Static Site Generator written in Python</em></p>
    <p><em>Born out of the need for simpler processes</em></p>
</p>

### To Be Updated